package comp2931.time;


import java.util.Timer;
import java.util.TimerTask;


/**
 * Instances of the Clock class print the current time on the console
 * at one-second intervals.  Using this class is simple; all you need to
 * do is create a Clock object and call its {@link #start} method:
 * <pre>
 * Clock myClock = new Clock();
 * myClock.start();
 * </pre>
 *
 * @author Nick Efford
 * @version 1.0 (2004-09-07)
 *
 * @see Time
 */
public class Clock extends TimerTask {

  protected Time time;
  private Timer ticker;


  /**
   * Creates a Clock object.
   * Note that this does <em>not</em> start it ticking!
   */
  public Clock() {
    time = new Time();
    ticker = new Timer(true);
  }


  /**
   * Starts this Clock object ticking.
   */
  public void start() {
    ticker.schedule(this, 0, 1000);
  }


  /**
   * Displays the current time on the console.
   */
  @Override public void run() {
    time.tick();
    System.out.println(time);
  }


  /**
   * Simple program to create a Clock object and start it ticking.
   *
   * @param args Command-line arguments, not used here
   */
  public static void main(String[] args) {
    Clock myClock = new Clock();
    myClock.start();

    try {
      // Wait for 10 seconds before terminating program
      Thread.sleep(10000);
    }
    catch (InterruptedException error) {
      // Should never happen
    }
  }
}
