package comp2931.time;

import org.junit.Before;
import org.junit.Test;

import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.*;

/**
 * Unit tests for the Time class.
 */
public class TimeTest {

  private Time midnight;
  private Time thirtySec;
  private Time thirtyMin;
  private Time noon;

  @Before
  public void setUp() {
    midnight = new Time(0, 0, 0);
    thirtySec = new Time(0, 0, 30);
    thirtyMin = new Time(0, 30, 0);
    noon = new Time(12, 0, 0);
  }

  @Test
  public void hours() {
    Time elevenPm = new Time(23, 0, 0);
    assertThat(midnight.getHours(), is(0));
    assertThat(noon.getHours(), is(12));
    assertThat(elevenPm.getHours(), is(23));
  }

  @Test(expected=IllegalArgumentException.class)
  public void hoursTooLow() {
    new Time(-1, 0, 0);
  }

  @Test(expected=IllegalArgumentException.class)
  public void hoursTooHigh() {
    new Time(24, 0, 0);
  }

  @Test
  public void minutes() {
    Time fiftyNineMin = new Time(0, 59, 0);
    assertThat(midnight.getMinutes(), is(0));
    assertThat(thirtyMin.getMinutes(), is(30));
    assertThat(fiftyNineMin.getMinutes(), is(59));
  }

  @Test(expected=IllegalArgumentException.class)
  public void minutesTooLow() {
    new Time(0, -1, 0);
  }

  @Test(expected=IllegalArgumentException.class)
  public void minutesTooHigh() {
    new Time(0, 60, 0);
  }

  @Test
  public void seconds() {
    Time fiftyNineSec = new Time(0, 0, 59);
    assertThat(midnight.getSeconds(), is(0));
    assertThat(thirtySec.getSeconds(), is(30));
    assertThat(fiftyNineSec.getSeconds(), is(59));
  }

  @Test(expected=IllegalArgumentException.class)
  public void secondsTooLow() {
    new Time(0, 0, -1);
  }

  @Test(expected=IllegalArgumentException.class)
  public void secondsTooHigh() {
    new Time(0, 0, 60);
  }

  @Test
  public void equality() {
    assertTrue(noon.equals(noon));
    assertTrue(noon.equals(new Time(12, 0, 0)));
    assertFalse(noon.equals(new Time(13, 0, 0)));
    assertFalse(noon.equals(new Time(12, 1, 0)));
    assertFalse(noon.equals(new Time(12, 0, 1)));
    assertFalse(noon.equals("12:00:00"));
  }

  @Test
  public void timeToString() {
    assertThat(midnight.toString(), is("00:00:00"));
    assertThat(noon.toString(), is("12:00:00"));
    assertThat(thirtyMin.toString(), is("00:30:00"));
    assertThat(thirtySec.toString(), is("00:00:30"));
  }
}
